@@ -1,5 +1,5 @@
 #create json
-barplotJSON<-function(height, xlab, ylab, ylim){
+barplotJSON<-function(height, xlab, ylab, ylim, cex){
 
 height <- data.matrix(height)
 
@@ -13,7 +13,10 @@ if(is.null(cnames))
 
 labels <- list(x = xlab, y = ylab)
 
-json <- list(data = height, rows = rnames, cols = cnames, labels = labels)
+if(!is.numeric(cex))
+  cex <- 1
+
+json <- list(data = height, rows = rnames, cols = cnames, labels = labels, cex = cex)
 
 if(!(length(ylim)==1 && is.na(ylim))){
   if(length(ylim)==1)
@@ -26,6 +29,6 @@ return(toJSON(json))
 
 
 #create html wrapper for barplot
-barplot_rjs<-function(height, xlab = "", ylab = "", ylim = NA, plot = TRUE, jupyter = FALSE, dir = "Barplot"){
-createHTML(dir, c("d3.min.js","jspdf.min.js","functions.js","barplot.js"), barplotJSON(height, xlab, ylab, ylim), plot, jupyter)
+barplot_rjs<-function(height, xlab = "", ylab = "", ylim = NA, cex = 1, plot = TRUE, jupyter = FALSE, dir = "Barplot"){
+createHTML(dir, c("d3.min.js","jspdf.min.js","functions.js","barplot.js"), barplotJSON(height, xlab, ylab, ylim, cex), plot, jupyter)
 }
